# Python Api

Since solver configuration files are sometimes machine generated, it can be arduous to manually create 
`distribute-jobs.yaml` files with methods like `distribute template`. To aid in this difficulty, a python
package is available to generate configurations with minimal effort.

## Full Documentation

Detailed documentation is found [here](./python/)
